﻿# EliteBGS

This tool is meant to help people contributing to the BGS effort to create BGS reports.
The tool allows you to configure BGS objectives, and will then parse your player journal
for tasks you completed relating to that BGS objective. Once the JSON player journal has
been parsed, you may then generate a BGS report you can copy/paste into Discord.

Source code is available [here](https://git.aror.org/florian/elitebgs).

Binary downloads can be found here: [https://bgs.n0la.org/](https://bgs.n0la.org/).

## How To

![Main Window Objectives](main-objectives.png)

Use the main tab to add objectives to the program. To do this, insert the system name,
faction, and, optionally, a station. Then press "Add Objective". Objectives can be deleted
by selecting them and pressing the "DEL" key. Manually added objectives like this are
enabled by default. You can always enable, and disable an objective by checking the box
next to its name. Disabled objectives are not included in the BGS discord log generation.

Once you have your objectives have been configured, you can press "Parse Journal", which
will check your Elite Dangerous player journal for completed missions. Currently the tool
recognises the following completed tasks:

* Completed missions
* Vouchers, including bounty vouchers, combat bonds, and settlement vouchers (aka intel packages)
* Selling of micro resources (Odyssey only)
* Selling cartography data
* Selling of cargo to stations

Please note that cartography data, and micro resources only help the controlling faction
of a station. The tool is clever enough to exclude these if the station you turn them in at, is not
controlled by the faction you specified in the objective.

There is no entry in the journal if you win a combat zone. So you have to add those manually. Select
an objective for which you wish to log a combat zone. The faction in the objective, must be the
faction you fought for in the combat zone. Then click "Add Combat Zone Win". Select type,
either "On Foot" for Odyssey, or "Ship" for regular ones. Then select the grade (low, medium or
high), and how many you won. Then press "Accept". Select "Cancel" to abort. You can of course remove
the combat zone entries by selecting them, and pressing "DEL".

If you deliberately fail a mission (to log negative INF towards a faction), the tool cannot detect
it, if the day you accepted the mission is outside of the given date range. It needs the journal
entry where you accept the mission to connect the mission to a faction, system and station. The tool
will warn you if this happens, with a message in the error log in the fourth tab.

![Main Window with entries](main-entries.png)

The window will then list all the journal entries it has found, and group them by objectives. You
can remove individual entries (if you think the tool detected something you thought was wrong), by
selecting the entry, and pressing the "DEL" key.

Once you are satisfied with the result, move to "Discord Report" tab, select a template, and click
"Generate Report".

![Generated Report](main-report.png)

Before you copy/paste it into the discord of your squadron, you should check the log. You can of
course edit it, if something is wrong or the tool itself missed something.

## Known Issues and Bugs

Settlement vouchers (aka Intel Packages) help every faction aligned with the given superpower.
So if you turn in an Imperial intel package on an imperial station, all factions aligned with
the Empire will gain a bit of INF boost. The tool currently cannot handle that. All intel packages
are displayed instead.

Sometimes bounty vouchers are not properly recognised. This is a bug in the player journal, where
the faction information is not properly written out in the journal:

```
{ 
  "timestamp":"2021-10-07T14:57:50Z", "event":"RedeemVoucher", 
  "Type":"bounty", "Amount":20750, 
  "Factions":[ { "Faction":"", "Amount":500 }, { "Faction":"", "Amount":20250 }]
}
```

Since the tool does not know for which faction these bounties were redeemed for, it cannot assign
it to an objective.

The player journal currently does not make an entry when you win or lose a combat zone. This is a
an ommission from FDev:

* [https://issues.frontierstore.net/issue-detail/43509](https://issues.frontierstore.net/issue-detail/43509)

Please upvote the issue to get it fixed. Until then, you have to add combat zone wins manually.

Also missions accepted from NPCs in Odyssey concourses do not get a player journal entry. This is
also an ommission from FDev:

* [https://issues.frontierstore.net/issue-detail/43586](https://issues.frontierstore.net/issue-detail/43586)

Until this is fixed, please edit the resulting BGS log text, and manually add such entries.

The tool also currently cannot differentiate between missions you have abandoned in the transaction
tab before it was completed, and those that you have failed - either delibaretly or by time-out. So
it will find and add them all, and you simply can remove those that you have abandoned manually.

## Use EDDB information

EliteBGS can download information from EDDB to auto complete system and station names. You can
enable its use in the "Settings". Once enabled, you must also press "Download", to download and
process the current version of the EDDB database.

Please note that the database is rather large (>200 MB), and processing it takes some time. It is
best if you don't use this feature if you are on a slow or metered internet connection. 

## Nothing's Perfect

The tool itself is still a work in progress, and it might miss something. If you think the tool
missed a task you have done, please contact `Hekateh` on the Elite Dangerous community discord. 
It would be helpful if you included the JSON player journal. This player journal can be found here:

```
%userprofile%\saved Games\Frontier Developments\Elite Dangerous\
```

## Build Dependencies

Handling of Elite Dangerous player journals have been moved to a separate project called `EDJournal`.
Its source can be found [here](https://git.aror.org/florian/edjournal). This project simply depends
on the binary DLL that `EDJournal` builds.

The project also requires `Ookii.Dialogs.WPF` controls, which contains the auto complete text box.

And of course, `Newtonsoft.Json` as the JSON parser.

## About

This tool was made by CMDR Hekateh (Discord: `nola#2457`).

Long live the Empire.